@@ -1,5 +1,6 @@
 import cv2
 import numpy as np
+import matplotlib.pyplot as plt
 
 
 def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=cv2.FONT_HERSHEY_SIMPLEX, fontsize=0.5,
@@ -46,12 +47,17 @@ def draw_bbox(frame, pt1, pt2, color, label=None, conf=None, thickness=1, font=c
     frame: arrray
         annotated image / frame
     '''
+    frame = frame.copy()
+    if frame.dtype == np.float32:
+        frame = (frame * 255).astype(np.uint8)
+
+    if isinstance(color, int):
+        color = tuple(c*255 for c in plt.cm.Set1(color)[:3])
+
     if is_normalized:
         h, w, c = frame.shape
         pt1 = pt1 * np.array([w, h])
-        pt1 = tuple(pt1.astype(int))
         pt2 = pt2 * np.array([w, h])
-        pt2 = tuple(pt2.astype(int))
 
     cv2.rectangle(frame, pt1, pt2, color, thickness)
 
